package ittp.protocol.parser;

import ittp.ittpException;
import ittp.protocol.response.Response;

/**
 * This class override the class TokenStream.
 * @author Frederic Bidon and Mathieu Texier
 */
abstract class TokenStream {
    /**Declaration of the several TokenStream used in the program*/
    final static int EOF = -100;
    final static int NL = -101;
    final static int SP = -102;
    final static int NUMBER = -103;
    
    final static int SLASH = -110;
    final static int DOUBLESLASH = -111;
    final static int COLON = -112;
    final static int COMA = -113;
    final static int MINUS = -114;
    
    final static int WORD = -200;
    
    final static int GET = -201;
    final static int HEAD = -202;
    final static int OPTIONS = -203;
    final static int TRACE = -204;
    
    final static int ITTP = -210;
    
    final static int CONNECTION = -220;
    final static int DATE= -221;
    final static int HOST= -222;
    final static int IF_MODIFIED_SINCE= -223;
    final static int RANGE= -224;
    public int tok;
    public String sval;
    public double nval;
    
    abstract public int next ();
    
    abstract public String next (int num);
    abstract public void filterString ();
    abstract public void setup ();
    
    /**
     * @param msg String containing the error message.
     * @return ParceException containing the message msg.
     */
    public ittpException ParseException (String msg) {
        return new ParseException (msg + "but found " + sval + " : " + tok);
    }
    
    /**
     * This class that extends the class ittpException send an exception when it is invoked.
     */
    class ParseException extends ittpException {
        /**
         * Constructor of the class
         * @param s String containing the error message.
         */
        public ParseException (String s) {
            super (s, Response.Code.ITTP_BAD_REQUEST);
        }
    }
}
