package ittp.protocol.request.headers;

import ittp.protocol.request.Request;
import ittp.ittpException;
import ittp.protocol.response.Response;

/**
 * This class analyse the header connection send by the client.
 * @author Frederic Bidon and Mathieu Texier
 */
public class Connection extends Request.Headers{
    static final public boolean OPEN = true;
    static final public boolean CLOSE = false;
    private boolean connection = OPEN;
    private boolean used = false;
    private Request parent;
    /**Constructor of the class*/
    public Connection (Request parent) {
        parent.super ();
        this.parent = parent;
    }
    
    /**
     * Mutators for the boolean connection.
     * @param connection boolean that determine if the connection is closed.
     * @throws ittpException if the headers Connection already received.
     */
    public void setConnection (boolean connection) throws ittpException {
        if (used)
            throw new ittpException ("headers Connection already received", Response.Code.ITTP_BAD_REQUEST);
        this.connection = connection;
        used = true;
    }
    
    /**
     * Accessors for the boolean connection.
     * @return connection: boolean that determine if the connection is closed.
     */
    public boolean getConnection () {
        return connection;
    }
    
    /**
     * Convert to a string the headers connection send by the client.
     * @return a string containing the response to this headers if it is used.
     */
    public String toString () {
        if (used)
            return "Connection:" + (connection ? "open" : "close") + "\n";
        else return "";
    }
    
    /**
     * Accessors for the boolean used.
     * @return used: boolean that determine if this headers is used.
     */
    public boolean isUsed () {
        return used;
    }
}